
# Type: pairwise interaction association_object




URI: [biolink:pairwise_interaction_association_object](https://w3id.org/biolink/vocab/pairwise_interaction_association_object)


## Domain and Range

[PairwiseInteractionAssociation](PairwiseInteractionAssociation.md) ->  <sub>REQ</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [PairwiseInteractionAssociation](PairwiseInteractionAssociation.md)
